@@ -209,14 +209,13 @@ class Text:
             device.close()
             extractedtext = retstr.getvalue()
             retstr.close()
+            with io.open('extractedTextAll/extractText.txt','w',encoding='utf-8') as f:
+                f.write(extractedtext)
+                f.close()
             return extractedtext
         except FileNotFoundError:
             print("[!] No File Found ")
             return
-        with open('extractedTextAll/extractText.txt','w') as f:
-            f.write(extractedtext)
-            f.close()
-        return extractedtext
 
     def extractTextSpecPage(self,page):
         if 'extractedTextAll' in os.listdir():
@@ -236,14 +235,14 @@ class Text:
 class Summarize:
     def __init__(self,address):
         self._address=address  #address
-        try:
-            nlp = spacy.load('en') #load 
-        except OSError:
-            print('Downloading language model for the spaCy POS tagger\n'
-            "(don't worry, this will only happen once)")
-            from spacy.cli import download   #download    
-            download('en')
-            nlp = spacy.load('en')
+        # try:
+        #     nlp = spacy.load('en') #load 
+        # except OSError:
+        #     print('Downloading language model for the spaCy POS tagger\n'
+        #     "(don't worry, this will only happen once)")
+        #     from spacy.cli import download   #download    
+        #     download('en')
+        #     nlp = spacy.load('en')
     def summarizer(self):
         text = Text(self._address)  #text
         text = text.extractTextAll() #extract 
